==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/Test/Gui/Resources/translations/Test_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ko" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <location filename="../../UnitTest.ui" line="16"/>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD 유닛테스트</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="31"/>
      <source>Failures and errors</source>
      <translation>실패와 오류</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="47"/>
      <source>Description</source>
      <translation>설명</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="82"/>
      <source>&amp;Start</source>
      <translation>시작(&amp;S)</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="85"/>
      <source>Alt+S</source>
      <translation>Alt + S</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="114"/>
      <source>&amp;Help</source>
      <translation>도움말(&amp;H)</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="117"/>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="127"/>
      <source>&amp;About</source>
      <translation>정보(&amp;A)</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="130"/>
      <source>Alt+A</source>
      <translation>Alt + A</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="140"/>
      <source>&amp;Close</source>
      <translation>닫기 &amp;C</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="143"/>
      <source>Alt+C</source>
      <translation>Alt + C</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="161"/>
      <source>Idle</source>
      <translation>유휴 상태</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="168"/>
      <source>Progress</source>
      <translation>진행 상황</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="197"/>
      <source>Remaining:</source>
      <translation>남음:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="214"/>
      <source>Errors:</source>
      <translation>오류:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="231"/>
      <source>Failures:</source>
      <translation>실패:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="248"/>
      <source>Run:</source>
      <translation>실행:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="258"/>
      <source>Test</source>
      <translation>테스트</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="270"/>
      <source>Select test name:</source>
      <translation>테스트 이름 선택:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <location filename="../../UnitTestImp.cpp" line="162"/>
      <source>Help</source>
      <translation>도움말</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="162"/>
      <source>Enter the name of a callable object which, when called, will return a TestCase.
Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it, including the stack trace.</source>
      <translation type="unfinished">Enter the name of a callable object which, when called, will return a TestCase.
Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it, including the stack trace.</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="174"/>
      <source>About FreeCAD UnitTest</source>
      <translation>FreeCAD 유닛테스트에 대하여</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="174"/>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for ones own modules.</source>
      <translation type="unfinished">Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for ones own modules.</translation>
    </message>
  </context>
</TS>

==> freecad_0.20.2+dfsg1.orig.tar.xz: FreeCAD-0.20.2/src/Mod/Test/Gui/Resources/translations/Test_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <location filename="../../UnitTest.ui" line="17"/>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD 유닛테스트</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="32"/>
      <source>Failures and errors</source>
      <translation>실패와 오류</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="48"/>
      <source>Description</source>
      <translation>설명</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="83"/>
      <source>&amp;Start</source>
      <translation>시작(&amp;S)</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="86"/>
      <source>Alt+S</source>
      <translation>Alt + S</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="115"/>
      <source>&amp;Help</source>
      <translation>도움말(&amp;H)</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="118"/>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="128"/>
      <source>&amp;About</source>
      <translation>정보(&amp;A)</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="131"/>
      <source>Alt+A</source>
      <translation>Alt + A</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="141"/>
      <source>&amp;Close</source>
      <translation>닫기 &amp;C</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="144"/>
      <source>Alt+C</source>
      <translation>Alt + C</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="162"/>
      <source>Idle</source>
      <translation>유휴 상태</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="169"/>
      <source>Progress</source>
      <translation>진행 상황</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="198"/>
      <source>Remaining:</source>
      <translation>남음:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="215"/>
      <source>Errors:</source>
      <translation>오류:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="232"/>
      <source>Failures:</source>
      <translation>실패:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="249"/>
      <source>Run:</source>
      <translation>실행:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="259"/>
      <source>Test</source>
      <translation>테스트</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="271"/>
      <source>Select test name:</source>
      <translation>테스트 이름 선택:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <location filename="../../UnitTestImp.cpp" line="152"/>
      <source>Help</source>
      <translation>도움말</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="152"/>
      <source>Enter the name of a callable object which, when called, will return a TestCase.
Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it, including the stack trace.</source>
      <translation>호출할 객체의 이름을 입력하세요. 입력한 객체가 호출되면 테스트 케이스를 반환합니다.
'시작'을 누르면 반환된 테스트케이스가 실행됩니다.

트리 뷰의 오류를 더블 클릭하면 스택 추적을 포함하여 더 자세한 정보를 확인할 수 있습니다</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="164"/>
      <source>About FreeCAD UnitTest</source>
      <translation>FreeCAD 유닛테스트에 대하여</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="164"/>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for ones own modules.</source>
      <translation>저작권 (c) Werner Mayer

FreeCAD 유닛테스트는 FreeCAD의 일부이며 모듈별로 유닛테스트를 작성할 수 있습니다.</translation>
    </message>
  </context>
</TS>
